@@ -2,7 +2,7 @@ import ast
 
 class PREFS(object):
     """docstring for PREFS"""
-    def __init__(self, prefs = {}, filename = "prefs", separator = "=", interprete = False):
+    def __init__(self, prefs, filename = "prefs", separator = "=", interprete = False):
         super(PREFS, self).__init__()
         self.prefs = prefs
         self.filename = filename
@@ -35,8 +35,11 @@ class PREFS(object):
             return content
 
         except FileNotFoundError:
-            self.CreatePrefs(self.prefs)
-            
+            try:
+                self.CreatePrefs(self.prefs())
+            except TypeError:
+                self.CreatePrefs(self.prefs)
+
     def CreatePrefs(self, prefsDictionarie):
         prefsTXT = open(f"{self.filename}.txt","w+")
         for i in prefsDictionarie.items():
